@@ -83,6 +83,25 @@ show_popupmenu( url, slot ); \
     "<menuitem action='PreferenceBoard'/>" \
     "</popup>" \
 
+#define POPUPMENU_ARRANGE_BASE \
+    "<menuitem action='Arrange_Type'/>" \
+    "<menuitem action='Arrange_Name'/>" \
+    "</menu>" \
+    "<separator/>"
+
+#define POPUPMENU_ARRANGE \
+    "<menu action='Arrange_Menu'>" \
+    POPUPMENU_ARRANGE_BASE
+
+#define POPUPMENU_ARRANGEDIR \
+    "<menu action='ArrangeDir_Menu'>" \
+    POPUPMENU_ARRANGE_BASE
+
+#define POPUPMENU_DELETE \
+    "<menu action='Delete_Menu'>" \
+    "<menuitem action='Delete'/>" \
+    "</menu>"
+
 #define POPUPMENU_SELECT \
     "<menuitem action='CopyURL'/>" \
     "<menuitem action='CopyTitleURL'/>" \
@@ -91,9 +110,9 @@ show_popupmenu( url, slot ); \
     "<menuitem action='NewDir'/>" \
     "<menuitem action='NewCom'/>" \
     "<separator/>" \
-    "<menu action='Delete_Menu'>" \
-    "<menuitem action='Delete'/>" \
-    "</menu>" \
+    POPUPMENU_ARRANGE \
+    "<separator/>" \
+    POPUPMENU_DELETE \
     "<separator/>" \
     "<menuitem action='SearchCacheBoard'/>" \
     "<separator/>" \
@@ -154,6 +173,12 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
     m_treeview.create_column( CONFIG::get_tree_ypad() );
     m_treeview.set_column_for_height( 0 );
 
+#if GTKMMVER >= 2120
+    // エクスパンダ表示とレベルインデント
+    m_treeview.set_show_expanders( CONFIG::get_tree_show_expanders() );
+    m_treeview.set_level_indentation( CONFIG::get_tree_level_indent() );
+#endif
+
     // treeviewのシグナルにコネクト
     m_treeview.signal_row_expanded().connect( sigc::mem_fun(*this, &BBSListViewBase::slot_row_exp ) );
     m_treeview.signal_row_collapsed().connect( sigc::mem_fun(*this, &BBSListViewBase::slot_row_col ) );        
@@ -202,6 +227,13 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
     action_group()->add( Gtk::Action::create( "CancelCheckUpdate", "キャンセル(_C)" ),
                          sigc::mem_fun( *this, &BBSListViewBase::stop ) );
 
+    action_group()->add( Gtk::Action::create( "Arrange_Menu", "並び替え(_G)" ) );
+    action_group()->add( Gtk::Action::create( "ArrangeDir_Menu", "ディレクトリ内の並び替え(_G)" ) );
+    action_group()->add( Gtk::Action::create( "Arrange_Type", "種類順(_T)"),
+                         sigc::bind< int >( sigc::mem_fun( *this, &BBSListViewBase::slot_sort ), SKELETON::SORT_BY_TYPE ) );
+    action_group()->add( Gtk::Action::create( "Arrange_Name", "名前順(_N)"),
+                         sigc::bind< int >( sigc::mem_fun( *this, &BBSListViewBase::slot_sort ), SKELETON::SORT_BY_NAME ) );
+
     action_group()->add( Gtk::Action::create( "OpenAsBoard", "ディレクトリをスレ一覧に表示(_B)"), sigc::mem_fun( *this, &BBSListViewBase::slot_opendir_as_board ) );
     action_group()->add( Gtk::Action::create( "CreateVBoard", "仮想板作成(_V)"), sigc::mem_fun( *this, &BBSListViewBase::slot_create_vboard ) );
     action_group()->add( Gtk::Action::create( "SearchCacheBoard", "キャッシュ内ログ検索(_S)"), sigc::mem_fun( *this, &BBSListViewBase::slot_search_cache_board ) );
@@ -293,9 +325,7 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
     "</menu>"
     "<separator/>"
 
-    "<menu action='Delete_Menu'>"
-    "<menuitem action='Delete'/>"
-    "</menu>"
+    POPUPMENU_DELETE
     "</popup>"
 
     // お気に入り + 何もないところをクリック
@@ -323,9 +353,9 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
     "<menuitem action='OpenAsBoard'/>"
     "<menuitem action='CreateVBoard'/>"
     "<separator/>"
-    "<menu action='Delete_Menu'>"
-    "<menuitem action='Delete'/>"
-    "</menu>"
+    POPUPMENU_ARRANGEDIR
+    "<separator/>"
+    POPUPMENU_DELETE
     "</popup>"
 
     // お気に入り + コメント
@@ -334,9 +364,9 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
     "<menuitem action='NewDir'/>"
     "<menuitem action='NewCom'/>"
     "<separator/>"
-    "<menu action='Delete_Menu'>"
-    "<menuitem action='Delete'/>"
-    "</menu>"
+    POPUPMENU_ARRANGE
+    "<separator/>"
+    POPUPMENU_DELETE
     "</popup>"
 
     // お気に入り + 仮想板
@@ -347,9 +377,9 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
     "<menuitem action='NewDir'/>"
     "<menuitem action='NewCom'/>"
     "<separator/>"
-    "<menu action='Delete_Menu'>"
-    "<menuitem action='Delete'/>"
-    "</menu>"
+    POPUPMENU_ARRANGE
+    "<separator/>"
+    POPUPMENU_DELETE
     "</popup>"
 
     //////////////////////////////////////
@@ -895,7 +925,12 @@ const bool BBSListViewBase::operate_view( const int control )
             CORE::core_set_command( "toggle_menubar" );
             break;
 
-            // お気に入り更新チェック
+            // メインツールバー表示/非表示
+        case CONTROL::ShowToolBarMain:
+            CORE::core_set_command( "toggle_toolbarmain" );
+            break;
+
+            // サイドバー更新チェック
         case CONTROL::CheckUpdateRoot:
             CORE::core_set_command( "check_update_root" );
             break;
@@ -1466,7 +1501,13 @@ void BBSListViewBase::add_newetcboard( const bool move, // true なら編集モ
 
         // .htmlを取り除く
         JDLIB::Regex regex;
-        if( regex.exec( "(.*)/[^/]+\\.html?$" , url ) ) url = regex.str( 1 );
+        const size_t offset = 0;
+        const bool icase = false;
+        const bool newline = true;
+        const bool usemigemo = false;
+        const bool wchar = false;
+
+        if( regex.exec( "(.*)/[^/]+\\.html?$" , url, offset, icase, newline, usemigemo, wchar ) ) url = regex.str( 1 );
 
         // 末尾の / を取り除く
         while( url.rfind( "/" ) == url.length() -1 ) url = url.substr( 0, url.length() -1 );
@@ -1475,7 +1516,7 @@ void BBSListViewBase::add_newetcboard( const bool move, // true なら編集モ
         url += "/";
 
         // boardid 取得
-        if( ! regex.exec( "(http://.*)/([^/]*)/$" , url ) ){
+        if( ! regex.exec( "(http://.*)/([^/]*)/$" , url, offset, icase, newline, usemigemo, wchar ) ){
             SKELETON::MsgDiag mdiag( get_parent_win(), "アドレスが不正な形式になっています", false, Gtk::MESSAGE_ERROR );
             mdiag.run();
             mdiag.hide();
@@ -1528,7 +1569,9 @@ void BBSListViewBase::add_newetcboard( const bool move, // true なら編集モ
             const bool before = false;
             const bool scroll = false;
             const bool force = true;  // 強制的に追加
-            m_treeview.append_info( list_info, m_path_selected, before, scroll, force );
+            const bool cancel_undo_commit = false;
+            const bool check_dup = false;
+            m_treeview.append_info( list_info, m_path_selected, before, scroll, force, cancel_undo_commit, check_dup );
             m_path_selected = m_treeview.get_current_path();
 
             // etc.txt保存
@@ -1772,7 +1815,7 @@ void BBSListViewBase::slot_search_cache_board()
     if( m_path_selected.empty() ) return;
     std::string url = path2url( m_path_selected );
 
-    CORE::core_set_command( "open_article_searchlog", url );
+    CORE::core_set_command( "open_article_searchlog", url, "", "noexec" );
 }
 
 
@@ -2030,6 +2073,12 @@ void BBSListViewBase::slot_checkupdate_open_selected_rows()
 }
 
 
+void BBSListViewBase::slot_sort( const int mode )
+{
+    m_treeview.sort( m_path_selected, mode );
+}
+
+
 //
 // path -> url 変換
 //
@@ -2647,8 +2696,17 @@ void BBSListViewBase::exec_search()
     std::cout << "BBSListViewBase::exec_search() path = " << path.to_string() << " query = " << query << std::endl;
 #endif
 	
-    regex_name.compile( query, true, true, true );
-    regex_url.compile( query, true );
+    const bool icase_name = true; // 大文字小文字区別しない
+    const bool newline_name = true; // . に改行をマッチさせない
+    const bool usemigemo_name = true; // migemo使用
+    const bool wchar_name = true;  // 全角半角の区別をしない
+    regex_name.compile( query, icase_name, newline_name, usemigemo_name, wchar_name );
+
+    const bool icase_url = true; // 大文字小文字区別しない
+    const bool newline_url = true;
+    const bool usemigemo_url = false;
+    const bool wchar_url = false;
+    regex_url.compile( query, icase_url, newline_url, usemigemo_url, wchar_url );
 
     bool hit = false;
     for(;;){
@@ -2682,7 +2740,8 @@ void BBSListViewBase::exec_search()
         Glib::ustring name = path2name( path );
         Glib::ustring url = path2url( path );
 
-        if( regex_name.exec( name, 0 ) || regex_url.exec( url, 0 ) ) hit = true;
+        const size_t offset = 0;
+        if( regex_name.exec( name, offset ) || regex_url.exec( url, offset ) ) hit = true;
 
         // 一周したら終わり
         if( path == path_start ) break;
@@ -2755,7 +2814,6 @@ void BBSListViewBase::append_item()
 
     bool before = false;
     Gtk::TreePath path;
-    const bool scroll = true;
 
     const std::string path_str = diag.get_path();
     if( list_info_bkup.size() == 1 && ! diag.get_name().empty() ) ( *list_info_bkup.begin() ).name = diag.get_name();
@@ -2770,7 +2828,12 @@ void BBSListViewBase::append_item()
 
     else path = Gtk::TreePath( path_str );
 
-    const CORE::DATA_INFO_LIST list_info = m_treeview.append_info( list_info_bkup, path, before, scroll );
+    const bool scroll = true;
+    const bool force = false;
+    const bool cancel_undo_commit = false;
+    const bool check_dup = true; // 重複チェック
+
+    const CORE::DATA_INFO_LIST list_info = m_treeview.append_info( list_info_bkup, path, before, scroll, force, cancel_undo_commit, check_dup );
     CORE::SBUF_clear_info();
     slot_dropped_from_other( list_info );
 
