@@ -373,7 +373,7 @@ void DBTREE::board_stop_load( const std::string& url )
 }
 
 
-std::list< DBTREE::ArticleBase* >& DBTREE::board_list_subject( const std::string& url )
+std::vector< DBTREE::ArticleBase* >& DBTREE::board_list_subject( const std::string& url )
 {
     return DBTREE::get_board( url )->get_list_subject();
 }
@@ -431,12 +431,22 @@ const bool DBTREE::board_check_noname( const std::string& url )
     return DBTREE::get_board( url )->get_check_noname();
 }
 
-
-void DBTREE::board_set_check_noname( const std::string& url, bool check )
+void DBTREE::board_set_check_noname( const std::string& url, const bool check )
 {
     DBTREE::get_board( url )->set_check_noname( check );
 }
 
+const bool DBTREE::board_show_oldlog( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_show_oldlog();
+}
+
+void DBTREE::board_set_show_oldlog( const std::string& url, const bool show )
+{
+    DBTREE::get_board( url )->set_show_oldlog( show );
+}
+
+
 const int DBTREE::board_get_mode_local_proxy( const std::string& url )
 {
     return DBTREE::get_board( url )->get_mode_local_proxy();
@@ -540,15 +550,16 @@ void DBTREE::read_boardinfo_all()
     DBTREE::get_root()->read_boardinfo_all();
 }
 
-void DBTREE::search_cache_all( std::list< DBTREE::ArticleBase* >& list_article,
-                               const std::string& query, const bool mode_or, const bool& stop )
+void DBTREE::search_cache_all( std::vector< DBTREE::ArticleBase* >& list_article,
+                               const std::string& query, const bool mode_or, const bool bm, const bool& stop )
 {
-    DBTREE::get_root()->search_cache( list_article, query, mode_or, stop );
+    DBTREE::get_root()->search_cache( list_article, query, mode_or, bm, stop );
 }
 
-void DBTREE::search_cache( const std::string& url, std::list< DBTREE::ArticleBase* >& list_article, const std::string& query, const bool mode_or, const bool& stop )
+void DBTREE::search_cache( const std::string& url, std::vector< DBTREE::ArticleBase* >& list_article, const std::string& query,
+                           const bool mode_or, const bool bm, const bool& stop )
 {
-    DBTREE::get_board( url )->search_cache( list_article, query, mode_or, stop );
+    DBTREE::get_board( url )->search_cache( list_article, query, mode_or, bm, stop );
 }
 
 void DBTREE::board_update_writetime( const std::string& url )
@@ -687,6 +698,11 @@ const std::list< std::string >& DBTREE::get_abone_list_thread( const std::string
     return DBTREE::get_board( url )->get_abone_list_thread();
 }
 
+const std::list< std::string >& DBTREE::get_abone_list_thread_remove( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_abone_list_thread_remove();
+}
+
 const std::list< std::string >& DBTREE::get_abone_list_word_thread( const std::string& url )
 {
     return DBTREE::get_board( url )->get_abone_list_word_thread();
@@ -723,9 +739,11 @@ void DBTREE::reset_abone_thread( const std::string& url,
                                  const std::list< std::string >& words,
                                  const std::list< std::string >& regexs,
                                  const int number,
-                                 const int hour )
+                                 const int hour,
+                                 const bool redraw
+    )
 {
-    DBTREE::get_board( url )->reset_abone_thread( threads, words, regexs, number, hour );
+    DBTREE::get_board( url )->reset_abone_thread( threads, words, regexs, number, hour, redraw );
 }
 
 /////////////////////////////////////////////////
@@ -1055,6 +1073,18 @@ void DBTREE::update_abone_all_article()
 }
 
 
+// 全articlebaseクラスの書き込み時間とスレ立て時間の文字列をリセット
+void DBTREE::reset_all_write_date()
+{
+    DBTREE::get_root()->reset_all_write_date();
+}
+
+void DBTREE::reset_all_since_date()
+{
+    DBTREE::get_root()->reset_all_since_date();
+}
+
+
 const std::list< std::string >& DBTREE::get_abone_list_id( const std::string& url )
 {
     return DBTREE::get_article( url )->get_abone_list_id();
