@@ -719,6 +719,11 @@ const bool ImageViewBase::operate_view( const int control )
             CORE::core_set_command( "toggle_menubar" );
             break;
 
+            // メインツールバー表示/非表示
+        case CONTROL::ShowToolBarMain:
+            CORE::core_set_command( "toggle_toolbarmain" );
+            break;
+
             // お気に入りに追加
         case CONTROL::AppendFavorite:
             slot_favorite();
@@ -883,6 +888,9 @@ void ImageViewBase::slot_reload_force()
     if( ! m_enable_menuslot ) return;
 
     if( ! SESSION::is_online() ){
+
+        CORE::core_set_command( "hide_popup" );
+
         SKELETON::MsgDiag mdiag( get_parent_win(), "オフラインです" );
         mdiag.run();
         return;
@@ -904,9 +912,12 @@ void ImageViewBase::slot_cancel_mosaic()
     if( ! m_enable_menuslot ) return;
 
     if( ! m_img->is_cached() ) return;
+    if( ! m_img->get_mosaic() ) return;
 
     if( m_img->is_fake() ){
 
+        CORE::core_set_command( "hide_popup" );
+
         std::string type = "本当の画像タイプは";
         switch( DBIMG::get_type_real( get_url() ) ){
             case DBIMG::T_JPG: type += "JPEG"; break;
