@@ -9,6 +9,7 @@
 
 #include "jdlib/confloader.h"
 #include "jdlib/miscutil.h"
+#include "jdlib/misctime.h"
 
 #include "bbslist/bbslistadmin.h"
 #include "article/articleadmin.h"
@@ -64,11 +65,15 @@ std::vector< int > items_board_col;
 std::string items_msg_toolbar_str;
 std::vector< int > items_msg_toolbar;
 
+std::string items_board_menu_str;
+std::vector< int > items_board_menu;
+
 std::string items_article_menu_str;
 std::vector< int > items_article_menu;
 
 int board_col_mark;
 int board_col_id;
+int board_col_board;
 int board_col_subject;
 int board_col_number;
 int board_col_load;
@@ -77,10 +82,14 @@ int board_col_since;
 int board_col_write;
 int board_col_speed;
 
+int board_col_since_time;
+int board_col_write_time;
+
 bool win_show_sidebar;
 
 bool win_show_menubar;
 
+bool show_main_toolbar;
 int win_toolbar_pos;
 
 bool show_bbslist_toolbar;
@@ -169,6 +178,7 @@ const int SESSION::parse_item( const std::string& item_name )
 
     else if( item_name == ITEM_NAME_MARK ) item = ITEM_MARK;
     else if( item_name == ITEM_NAME_ID ) item = ITEM_ID;
+    else if( item_name == ITEM_NAME_BOARD ) item = ITEM_BOARD;
     else if( item_name == ITEM_NAME_NAME ) item = ITEM_NAME;
     else if( item_name == ITEM_NAME_RES ) item = ITEM_RES;
     else if( item_name == ITEM_NAME_LOAD ) item = ITEM_LOAD;
@@ -179,17 +189,24 @@ const int SESSION::parse_item( const std::string& item_name )
 
     else if( item_name == ITEM_NAME_WRITEMSG ) item = ITEM_WRITEMSG;
     else if( item_name == ITEM_NAME_OPENBOARD ) item = ITEM_OPENBOARD;
+    else if( item_name == ITEM_NAME_OPENARTICLETAB ) item = ITEM_OPENARTICLETAB;
+    else if( item_name == ITEM_NAME_REGETARTICLE ) item = ITEM_REGETARTICLE;
+    else if( item_name == ITEM_NAME_BOOKMARK ) item = ITEM_BOOKMARK;
     else if( item_name == ITEM_NAME_SEARCH ) item = ITEM_SEARCH;
     else if( item_name == ITEM_NAME_DRAWOUT ) item = ITEM_DRAWOUT;
     else if( item_name == ITEM_NAME_RELOAD ) item = ITEM_RELOAD;
     else if( item_name == ITEM_NAME_STOPLOADING ) item = ITEM_STOPLOADING;
     else if( item_name == ITEM_NAME_FAVORITE ) item = ITEM_FAVORITE;
+    else if( item_name == ITEM_NAME_FAVORITE_ARTICLE ) item = ITEM_FAVORITE_ARTICLE;
     else if( item_name == ITEM_NAME_CHECK_UPDATE_ROOT ) item = ITEM_CHECK_UPDATE_ROOT;
     else if( item_name == ITEM_NAME_CHECK_UPDATE_OPEN_ROOT ) item = ITEM_CHECK_UPDATE_OPEN_ROOT;
+
     else if( item_name == ITEM_NAME_COPY ) item = ITEM_COPY;
     else if( item_name == ITEM_NAME_COPY_URL ) item = ITEM_COPY_URL;
     else if( item_name == ITEM_NAME_COPY_TITLE_URL ) item = ITEM_COPY_TITLE_URL;
     else if( item_name == ITEM_NAME_COPY_TITLE_URL_THREAD ) item = ITEM_COPY_TITLE_URL_THREAD;
+    else if( item_name == ITEM_NAME_COPY_THREAD_INFO ) item = ITEM_COPY_THREAD_INFO;
+
     else if( item_name == ITEM_NAME_DELETE ) item = ITEM_DELETE;
     else if( item_name == ITEM_NAME_QUIT ) item = ITEM_QUIT;
     else if( item_name == ITEM_NAME_PREVVIEW ) item = ITEM_PREVVIEW;
@@ -201,6 +218,7 @@ const int SESSION::parse_item( const std::string& item_name )
     else if( item_name == ITEM_NAME_SEARCHBOX ) item = ITEM_SEARCHBOX;
     else if( item_name == ITEM_NAME_SEARCH_NEXT ) item = ITEM_SEARCH_NEXT;
     else if( item_name == ITEM_NAME_SEARCH_PREV ) item = ITEM_SEARCH_PREV;
+    else if( item_name == ITEM_NAME_NEXTARTICLE ) item = ITEM_NEXTARTICLE;
 
     else if( item_name == ITEM_NAME_INSERTTEXT ) item = ITEM_INSERTTEXT;
     else if( item_name == ITEM_NAME_LOCK_MESSAGE ) item = ITEM_LOCK_MESSAGE;
@@ -211,13 +229,17 @@ const int SESSION::parse_item( const std::string& item_name )
 
     else if( item_name == ITEM_NAME_NGWORD ) item = ITEM_NGWORD;
     else if( item_name == ITEM_NAME_ABONE_SELECTION ) item = ITEM_ABONE_SELECTION;
+    else if( item_name == ITEM_NAME_ABONE_ARTICLE ) item = ITEM_ABONE_ARTICLE;
     else if( item_name == ITEM_NAME_QUOTE_SELECTION ) item = ITEM_QUOTE_SELECTION;
     else if( item_name == ITEM_NAME_OPEN_BROWSER ) item = ITEM_OPEN_BROWSER;
     else if( item_name == ITEM_NAME_USER_COMMAND ) item = ITEM_USER_COMMAND;
     else if( item_name == ITEM_NAME_ETC ) item = ITEM_ETC;
     else if( item_name == ITEM_NAME_SAVE_DAT ) item = ITEM_SAVE_DAT;
-    else if( item_name == ITEM_NAME_COPY_THREAD_INFO ) item = ITEM_COPY_THREAD_INFO;
+    else if( item_name == ITEM_NAME_SELECTIMG ) item = ITEM_SELECTIMG;
+    else if( item_name == ITEM_NAME_SELECTDELIMG ) item = ITEM_SELECTDELIMG;
+    else if( item_name == ITEM_NAME_SELECTABONEIMG ) item = ITEM_SELECTABONEIMG;
 
+    else if( item_name == ITEM_NAME_PREF_BOARD ) item = ITEM_PREF_BOARD;
     else if( item_name == ITEM_NAME_PREF_THREAD ) item = ITEM_PREF_THREAD;
 
     return item;
@@ -305,6 +327,7 @@ void SESSION::init_session()
 
     win_show_menubar = cf.get_option_bool( "show_menubar", true );
 
+    show_main_toolbar = cf.get_option_bool( "show_main_toolbar", true );
     win_toolbar_pos = cf.get_option_int( "toolbar_pos", TOOLBAR_POS_NORMAL, 0, TOOLBAR_POS_NUM -1 );
 
     show_bbslist_toolbar = cf.get_option_bool( "show_bbslist_toolbar", true );
@@ -360,6 +383,10 @@ void SESSION::init_session()
     items_board_col_str = cf.get_option_str( "items_board", get_items_board_col_default_str() );
     items_board_col =  parse_items( items_board_col_str );
 
+    // スレ一覧のコンテキストメニュー項目
+    items_board_menu_str = cf.get_option_str( "items_board_menu", get_items_board_menu_default_str() );
+    items_board_menu =  parse_items( items_board_menu_str );
+
     // スレビューのコンテキストメニュー項目
     items_article_menu_str = cf.get_option_str( "items_article_menu", get_items_article_menu_default_str() );
     items_article_menu =  parse_items( items_article_menu_str );
@@ -367,6 +394,7 @@ void SESSION::init_session()
     // board ビューの列幅
     board_col_mark = cf.get_option_int( "col_mark", 30, 4, 8192 );
     board_col_id = cf.get_option_int( "col_id", 45, 4, 8192 );
+    board_col_board = cf.get_option_int( "col_board", 70, 4, 8192 );
     board_col_subject = cf.get_option_int( "col_subject", 190, 4, 8192 );
     board_col_number = cf.get_option_int( "col_number", 45, 4, 8192 );
     board_col_load = cf.get_option_int( "col_load", 45, 4, 8192 );
@@ -375,6 +403,12 @@ void SESSION::init_session()
     board_col_write = cf.get_option_int( "col_write", 70, 4, 8192 );
     board_col_speed = cf.get_option_int( "col_speed", 45, 4, 8192 );
 
+    // スレ一覧の since の表示モード
+    board_col_since_time = cf.get_option_int( "col_since_time", MISC::TIME_NORMAL, 0, MISC::TIME_NUM-1 );
+
+    // スレ一覧の 最終書込 の表示モード
+    board_col_write_time = cf.get_option_int( "col_write_time", MISC::TIME_NORMAL, 0, MISC::TIME_NUM-1 );
+
     embedded_img = cf.get_option_bool( "embedded_img", true );
 
     x_win_img = cf.get_option_int( "x_win_img", 0, 0, 8192 );
@@ -444,6 +478,7 @@ void SESSION::init_session()
     std::cout << "columns\n"
               << board_col_mark << std::endl
               << board_col_id << std::endl
+              << board_col_board << std::endl
               << board_col_subject << std::endl
               << board_col_number << std::endl
               << board_col_load << std::endl
@@ -521,6 +556,7 @@ void SESSION::save_session()
         << "width = " << width_win_main << std::endl
         << "height = " << height_win_main << std::endl
         << "maximized = " << maximized_win_main << std::endl
+        << "show_main_toolbar = " << show_main_toolbar << std::endl
         << "toolbar_pos = " << win_toolbar_pos << std::endl
         << "show_bbslist_toolbar = " << show_bbslist_toolbar << std::endl
         << "show_board_toolbar = " << show_board_toolbar << std::endl
@@ -559,10 +595,12 @@ void SESSION::save_session()
         << "items_board_toolbar = " << items_board_toolbar_str << std::endl
         << "items_msg_toolbar = " << items_msg_toolbar_str << std::endl
         << "items_board = " << items_board_col_str << std::endl
+        << "items_board_menu = " << items_board_menu_str << std::endl
         << "items_article_menu = " << items_article_menu_str << std::endl
 
         << "col_mark = " << board_col_mark << std::endl
         << "col_id = " << board_col_id << std::endl
+        << "col_board = " << board_col_board << std::endl    
         << "col_subject = " << board_col_subject << std::endl
         << "col_number = " << board_col_number << std::endl
         << "col_load = " << board_col_load << std::endl
@@ -571,6 +609,9 @@ void SESSION::save_session()
         << "col_write = " << board_col_write << std::endl
         << "col_speed = " << board_col_speed << std::endl
 
+        << "col_since_time = " << board_col_since_time << std::endl
+        << "col_write_time = " << board_col_write_time << std::endl
+
         << "embedded_img = " << embedded_img << std::endl
         << "x_win_img = " << x_win_img << std::endl
         << "y_win_img = " << y_win_img << std::endl
@@ -628,7 +669,9 @@ const bool SESSION::show_sidebar(){ return win_show_sidebar; }
 const bool SESSION::show_menubar(){ return win_show_menubar; }
 void SESSION::set_show_menubar( const bool show ){ win_show_menubar = show; }
 
-const int SESSION::toolbar_pos(){ return win_toolbar_pos; }
+const bool SESSION::get_show_main_toolbar(){ return show_main_toolbar; }
+void SESSION::set_show_main_toolbar( const bool show ){ show_main_toolbar = show; }
+const int SESSION::get_toolbar_pos(){ return win_toolbar_pos; }
 void SESSION::set_toolbar_pos( const int pos ){ win_toolbar_pos = pos; }
 
 const bool SESSION::get_show_bbslist_toolbar(){ return show_bbslist_toolbar; }
@@ -911,6 +954,36 @@ void SESSION::set_items_board_col_str( const std::string& items_str )
 }
 const int SESSION::get_item_board_col( const int num ){ return items_board_col[ num ]; }
 
+// スレ一覧のコンテキストメニュー項目
+const std::string& SESSION::get_items_board_menu_str(){ return items_board_menu_str; }
+const std::string SESSION::get_items_board_menu_default_str()
+{
+    return
+    ITEM_NAME_BOOKMARK + std::string ( " " ) +
+    ITEM_NAME_SEPARATOR + std::string ( " " ) +
+    ITEM_NAME_OPENARTICLETAB + std::string ( " " ) +
+    ITEM_NAME_OPEN_BROWSER + std::string ( " " ) +
+    ITEM_NAME_SEPARATOR + std::string ( " " ) +
+    ITEM_NAME_COPY_URL + std::string ( " " ) +
+    ITEM_NAME_COPY_TITLE_URL_THREAD + std::string ( " " ) +
+    ITEM_NAME_SEPARATOR + std::string ( " " ) +
+    ITEM_NAME_ABONE_ARTICLE + std::string ( " " ) +
+    ITEM_NAME_SEPARATOR + std::string ( " " ) +
+    ITEM_NAME_DELETE + std::string ( " " ) +
+    ITEM_NAME_SEPARATOR + std::string ( " " ) +
+    ITEM_NAME_ETC + std::string ( " " ) +
+    ITEM_NAME_SEPARATOR + std::string ( " " ) +
+    ITEM_NAME_PREF_THREAD + std::string ( " " ) +
+    ITEM_NAME_PREF_BOARD;
+}
+void SESSION::set_items_board_menu_str( const std::string& items_str )
+{
+    items_board_menu_str = items_str;
+    items_board_menu = parse_items( items_board_menu_str );
+}
+const int SESSION::get_item_board_menu( const int num ){ return items_board_menu[ num ]; }
+
+
 // スレビューのコンテキストメニュー項目
 const std::string& SESSION::get_items_article_menu_str(){ return items_article_menu_str; }
 const std::string SESSION::get_items_article_menu_default_str()
@@ -943,6 +1016,7 @@ const int SESSION::get_item_article_menu( const int num ){ return items_article_
 // board ビューの列幅
 const int SESSION::col_mark(){ return board_col_mark; }
 const int SESSION::col_id(){ return board_col_id; }
+const int SESSION::col_board(){ return board_col_board; }
 const int SESSION::col_subject(){ return board_col_subject; }
 const int SESSION::col_number(){ return board_col_number; }
 const int SESSION::col_load(){ return board_col_load; }
@@ -951,6 +1025,13 @@ const int SESSION::col_since(){ return board_col_since; }
 const int SESSION::col_write(){ return board_col_write; }
 const int SESSION::col_speed(){ return board_col_speed; }
 
+// スレ一覧の since の表示モード
+const int SESSION::get_col_since_time() { return board_col_since_time; }
+void SESSION::set_col_since_time( const int mode ){ board_col_since_time = mode; }
+
+// スレ一覧の 最終書込 の表示モード
+const int SESSION::get_col_write_time() { return board_col_write_time; }
+void SESSION::set_col_write_time( const int mode ){ board_col_write_time = mode; }
 
 // 現在開いているサイドバーのページ
 const int SESSION::get_sidebar_current_page()
@@ -967,6 +1048,7 @@ const std::string SESSION::get_sidebar_current_url()
 
 void SESSION::set_col_mark( const int width ){ board_col_mark = width; }
 void SESSION::set_col_id( const int width ){ board_col_id = width; }
+void SESSION::set_col_board( const int width ){ board_col_board = width; }
 void SESSION::set_col_subject( const int width ){ board_col_subject = width; }
 void SESSION::set_col_number( const int width ){ board_col_number = width; }
 void SESSION::set_col_load( const int width ){ board_col_load = width; }
@@ -1140,3 +1222,17 @@ void SESSION::get_history( const std::string& url, CORE::DATA_INFO_LIST& info_li
 {
     return BBSLIST::get_admin()->get_history( url, info_list );
 }
+
+
+// サイドバーの指定したidのディレクトリに含まれるスレのアドレスを取得
+void SESSION::get_sidebar_threads( const std::string& url, const int dirid, std::vector< std::string >& list_url )
+{
+    BBSLIST::get_admin()->get_threads( url, dirid, list_url );
+}
+
+
+// サイドバーの指定したidのディレクトリの名前を取得
+const std::string SESSION::get_sidebar_dirname( const std::string& url, const int dirid )
+{
+    return BBSLIST::get_admin()->get_dirname( url, dirid );
+}
